package main

import (
	"query-service/internal/adapters/brokeradapter"
	"query-service/internal/drivers/brokerdriver"
	"query-service/internal/drivers/keyvaluedriver"
	"query-service/internal/usecases/consume"
	"query-service/internal/usecases/convertquery"
	"query-service/internal/usecases/produce"
	"query-service/internal/usecases/request"
	"query-service/pkg/logger"
)

func main() {

	logger.Start()

	// MARK: Create relevant services
	redisService := keyvaluedriver.NewRedisDriver()

	// MARK: Create alice RabbitMQ services
	brokerGateway := brokeradapter.CreateGateway()
	aliceBroker := brokerdriver.CreateAliceBroker(brokerGateway)

	// Instantiate an implementation of the produce UseCase
	produceService := produce.NewService(aliceBroker, redisService)

	// MARK: Create relevant services for consuming a message
	convertQueryService := convertquery.NewService()

	requestSenderService := request.NewService()

	consumeService := consume.NewService(aliceBroker, produceService, convertQueryService, requestSenderService)

	// MARK: Start services
	redisService.Start()
	produceService.Start()

	go consumeService.Start()

	select {}
}
